<?php

namespace Drupal\bunny_cdn\EventSubscriber;

use Drupal\Core\Cache\CacheableResponseInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Generates a 'CDN-Tag' header in the format expected by BunnyCDN.
 */
class CdnTagResponseHeaderSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[KernelEvents::RESPONSE][] = ['onRespond'];
    return $events;
  }

  /**
   * Adds a 'CDN-Tag' header to the response.
   */
  public function onRespond(ResponseEvent $event): void {
    if (!$event->isMainRequest()) {
      return;
    }

    $response = $event->getResponse();
    if (!$response instanceof CacheableResponseInterface) {
      return;
    }

    $cacheMetadata = $response->getCacheableMetadata();
    $cacheTags = $cacheMetadata->getCacheTags();

    if ($cacheTags === []) {
      return;
    }

    $response->headers->set('CDN-Tag', implode(' ', $cacheTags));
  }

}
